@@ -23,6 +23,7 @@ bartMachine = function(X = NULL, y = NULL, Xy = NULL,
     impute_missingness_with_rf_impute = FALSE,
     impute_missingness_with_x_j_bar_for_lm = TRUE,
     mem_cache_for_speed = TRUE,
+	flush_indices_to_save_RAM = TRUE,
 	serialize = FALSE,
 	seed = NULL,
     verbose = TRUE){
@@ -51,6 +52,7 @@ bartMachine = function(X = NULL, y = NULL, Xy = NULL,
 	    impute_missingness_with_rf_impute,
 	    impute_missingness_with_x_j_bar_for_lm,
 	    mem_cache_for_speed,
+		flush_indices_to_save_RAM,
 		serialize,
 		seed,
 	    verbose)
